package Finance::Tax::Aruba::Income::2025;
our $VERSION = '0.011';
use Moose;
use namespace::autoclean;

# ABSTRACT: Income tax calculator for the year 2025

with qw(
    Finance::Tax::Aruba::Role::Income::TaxYear
);

has '+taxfree_max' => (
    default  => 30_000,
);

sub _build_tax_bracket {
    return [
        { min => 0, max => 34930, fixed => 0, rate => 0 },
        {
            min   => 34930,
            max   => 63904,
            fixed => 0,
            rate  => 21,
        },
        {
            min   => 63904,
            max   => 135527,
            fixed => 6084.54,
            rate  => 42
        },
        {
            min   => 135527,
            max   => 'inf' * 1,
            fixed => 36166.20,
            rate  => 52
        },
    ];
}

sub is_year {
    my $self = shift;
    my $year = shift;
    return 1 if $year == 2025;
    return 1 if $year == 2024;
    return 1 if $year == 2025;
    return 0;
}


__PACKAGE__->meta->make_immutable;

__END__

=pod

=encoding UTF-8

=head1 NAME

Finance::Tax::Aruba::Income::2025 - Income tax calculator for the year 2025

=head1 VERSION

version 0.011

=head1 SYNOPSIS

=head1 DESCRIPTION

Calculate your taxes and other social premiums for the year 2025

=head1 METHODS

=head2 is_year

Year selector method

    if ($module->is_year(2025)) {
        return "year is 2025";
    }

=head1 SEE ALSO

This class implements the L<Finance::Tax::Aruba::Role::Income::TaxYear> role.

L<AB2025No.001|https://www.gobierno.aw/nl/afkondigingsbladen-2024>
L<AB2025No.001|https://cuatro.sim-cdn.nl/arubaoverheid2858bd/uploads/ab2025no.1.pdf>

=head1 AUTHOR

Wesley Schwengle <waterkip@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2020 by Wesley Schwengle.

This is free software, licensed under:

  The (three-clause) BSD License

=cut
